Package: fresh
Title: Create Custom 'Bootstrap' Themes to Use in 'Shiny'
Version: 0.2.2
Authors@R: c(
  person("Victor", "Perrier", email = "victor.perrier@dreamrs.fr", role = c("aut", "cre", "cph")),
  person("Fanny", "Meyer", role = "aut"),
  person("Thomas", "Park", role = c("ctb", "cph"), comment = "Bootswatch themes"),
  person("Mark", "Otto", role = "ctb", comment = "Bootstrap library"),
  person("Jacob", "Thornton", role = "ctb", comment = "Bootstrap library"),
  person(family = "Bootstrap contributors", role = "ctb", comment = "Bootstrap library"),
  person(family = "Twitter, Inc", role = "cph", comment = "Bootstrap library"),
  person("onkbear", role = c("ctb", "cph"), comment = "admin-lte-2-sass"),
  person(family = "Colorlib", role = c("ctb", "cph"), comment = "AdminLTE"))
Description: Customize 'Bootstrap' and 'Bootswatch' themes, like colors, fonts, grid layout, 
  to use in 'Shiny' applications, 'rmarkdown' documents and 'flexdashboard'.
URL: https://github.com/dreamRs/fresh
BugReports: https://github.com/dreamRs/fresh/issues
License: GPL-3
Encoding: UTF-8
Imports: bslib, htmltools, rstudioapi, sass, shiny
Suggests: bsicons, shinyWidgets, shinydashboard, bs4Dash, knitr,
        rmarkdown, testthat (>= 2.1.0), covr
RoxygenNote: 7.3.2
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-09-04 12:32:06 UTC; perri
Author: Victor Perrier [aut, cre, cph],
  Fanny Meyer [aut],
  Thomas Park [ctb, cph] (Bootswatch themes),
  Mark Otto [ctb] (Bootstrap library),
  Jacob Thornton [ctb] (Bootstrap library),
  Bootstrap contributors [ctb] (Bootstrap library),
  Twitter, Inc [cph] (Bootstrap library),
  onkbear [ctb, cph] (admin-lte-2-sass),
  Colorlib [ctb, cph] (AdminLTE)
Maintainer: Victor Perrier <victor.perrier@dreamrs.fr>
Repository: CRAN
Date/Publication: 2025-09-04 13:00:02 UTC
Built: R 4.6.0; ; 2026-04-29 00:24:06 UTC; unix
